DataMart Python API: NYU
========================

The Python API provided by NYU is a wrapper around the [REST API](https://datadrivendiscovery.gitlab.io/datamart-api/rest_api.html).

To install:

    $ pip install datamart_nyu
